@@ -5,6 +5,9 @@ from typing import Dict
 class Label(Enum):
     HOSPITAL_NAME = "hospital_name"
     HOSPITAL_ADDRESS = "hospital_address"
+    HOSPITAL_CATEGORY = "hospital_category"
+    DISTRICT = "district"
+    AREA = "area"
     CONTACT_NUMBER = "contact_number"
 
     OFFICER_NAME = "officer_name"
@@ -36,7 +39,7 @@ class Label(Enum):
 str_to_label_map: Dict[str, Label] = {
     "hospital name": Label.HOSPITAL_NAME,
     "hospital address": Label.HOSPITAL_ADDRESS,
-}.update({})
+}
 
 
 def str_to_label(_str: str) -> Label:
